# Copyright:: Copyright (c) 2015 PagerDuty, Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and

from __future__ import print_function
import sys


def dot(char='.'):
    if sys.stderr.isatty():
        sys.stderr.write(char)
        sys.stderr.flush()


def output_issues(title, issues):
    print (title)
    print ('=' * len(title))
    for issue in [i for i in issues if i.fields.issuetype.name != 'Sub-task']:
        print (issue.key.ljust(10) + issue.fields.summary)
    print('\r')


def output_stats(title, stats, indent=0):
    print('\t' * indent + title)
    print('\t' * indent + '=' * len(title))
    for k, v in sorted(stats.iteritems()):
        if isinstance(v, float):
            v = round(v, 2)
        if isinstance(v, dict):
            output_stats(k, v, indent + 1)
        else:
            print('\t' * indent + k.ljust(20) + ':' + str(v))
    print('\r')



# Copyright:: Copyright (c) 2015 PagerDuty, Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and


def find_custom_field(field_name, jira):
    fields = jira.fields()
    for f in fields:
        if field_name in f['clauseNames']:
            return f


def find_board(board_name, greenhopper):
    boards = [b for b in greenhopper.boards() if b.name == board_name]
    if len(boards):
        return boards[0]
    return None


def find_sprint(sprint_name, board, greenhopper):
    sprints = [s for s in greenhopper.sprints(
        board.id) if s.name == sprint_name]
    if len(sprints):
        return sprints[0]
    return None


def find_project(project_name_or_key, jira):
    projects = [p for p in jira.projects()
                if p.name == project_name_or_key
                or p.key == project_name_or_key]
    if len(projects):
        return projects[0]
    return None


def fetch_subtasks(issues, jira):
    subtasks = jira.search_issues('parent in ({0})'.format(
        ','.join([i.key for i in issues])), expand='changelog', maxResults=-1)
    return subtasks



# Copyright:: Copyright (c) 2015 PagerDuty, Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and

from ConfigParser import SafeConfigParser
import os


def parse_config(args):
    settings = {}
    parser = SafeConfigParser()
    config_precedence = [
        '/etc/sprintstats.cfg',
        '/usr/local/etc/sprintstats.cfg',
        '~/.sprintstats.cfg',
        'config.cfg'
    ]
    config_file = None
    for f in config_precedence:
        if os.path.exists(f):
            config_file = f

    if args and args.config:
        if os.path.exists(args.config):
            config_file = args.config
        else:
            print('WARNING: Specified config file {0} not found'.format(
                (os.path.abspath(args.config))))
            if config_file and os.path.exists(config_file):
                print(
                    'Using {0} instead.'.format(os.path.abspath(config_file)))

    if config_file and os.path.exists(config_file):
        parser.read('config.cfg')
        if parser.has_section('default'):
            settings = dict(parser.items('default'))
    if 'default_points' not in settings:
        settings['default_points'] = 0
    return settings



from setuptools import setup

with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(name='pd-sprintstats',
      version='3.00',
      description='Gathers some statistics for a sprint from JIRA',
      author='Jason Diller',
      author_email='jdiller@pagerduty.com',
      url='',
      install_requires=required,
      scripts=['sprintstats', 'wikifysprint'],
      packages=['lib', 'templates'],
      pacakge_data={'templates':'templates/*.j2'},
      include_package_data=True,
)
